@@ -23,16 +23,17 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gconf/gconf-client.h>
 #include <panel-applet.h>
-#include <panel-applet-gconf.h>
 
 #include "global.h"
 
 static void
-about_cb (GtkAction       *action,
-	  MultiloadApplet *ma)
+about_cb (GSimpleAction *action,
+          GVariant      *parameter,
+          gpointer       user_data)
 {
+	MultiloadApplet *ma = (MultiloadApplet *) user_data;
+
     const gchar * const authors[] =
     {
 		"Martin Baulig <martin@home-of-linux.org>",
@@ -64,10 +65,11 @@ about_cb (GtkAction       *action,
 }
 
 static void
-help_cb (GtkAction       *action,
-	 MultiloadApplet *ma)
+help_cb (GSimpleAction *action,
+         GVariant      *parameter,
+         gpointer       user_data)
 {
-
+	MultiloadApplet *ma = (MultiloadApplet *) user_data;
  	GError *error = NULL;
                                                                                 
 	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
@@ -98,8 +100,8 @@ start_procman (MultiloadApplet *ma)
 
 	g_return_if_fail (ma != NULL);
 
-	monitor = panel_applet_gconf_get_string (ma->applet, "system_monitor", NULL);
-	if (monitor == NULL)
+	monitor = g_settings_get_string (ma->settings, KEY_SYSTEM_MONITOR);
+	if (IS_STRING_EMPTY (monitor))
 	        monitor = g_strdup ("gnome-system-monitor.desktop");
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (ma->applet));
@@ -166,20 +168,29 @@ start_procman (MultiloadApplet *ma)
 }
               
 static void
-start_procman_cb (GtkAction       *action,
-		  MultiloadApplet *ma)
+start_procman_cb (GSimpleAction *action,
+                  GVariant      *parameter,
+                  gpointer       user_data)
 {
+	MultiloadApplet *ma = (MultiloadApplet *) user_data;
 	start_procman (ma);
 }
 
 static void
-multiload_change_size_cb(PanelApplet *applet, gint size, gpointer data)
+multiload_change_size_cb (PanelApplet *applet, GtkAllocation *allocation, gpointer data)
 {
 	MultiloadApplet *ma = (MultiloadApplet *)data;
-	
-	multiload_applet_refresh(ma);
-	
-	return;
+	PanelAppletOrient orient = panel_applet_get_orient (applet);
+	gint old_size = ma->size;
+
+	if (orient == PANEL_APPLET_ORIENT_LEFT || orient == PANEL_APPLET_ORIENT_RIGHT) {
+		ma->size = allocation->width;
+	} else {
+		ma->size = allocation->height;
+	}
+
+	if (old_size != ma->size)
+		multiload_applet_refresh(ma);
 }
 
 static void
@@ -210,7 +221,10 @@ multiload_destroy_cb(GtkWidget *widget, gpointer data)
 		load_graph_unalloc(ma->graphs[i]);
 		g_free(ma->graphs[i]);
 	}
-	
+
+	if (ma->settings)
+		g_object_unref (ma->settings);
+
 	if (ma->about_dialog)
 		gtk_widget_destroy (ma->about_dialog);
 	
@@ -369,8 +383,8 @@ multiload_create_graphs(MultiloadApplet *ma)
 	gint speed, size;
 	gint i;
 
-	speed = panel_applet_gconf_get_int (ma->applet, "speed", NULL);
-	size = panel_applet_gconf_get_int (ma->applet, "size", NULL);
+	speed = g_settings_get_int (ma->settings, KEY_SPEED);
+	size = g_settings_get_int (ma->settings, KEY_SIZE);
 	speed = MAX (speed, 50);
 	size = CLAMP (size, 10, 400);
 
@@ -379,15 +393,8 @@ multiload_create_graphs(MultiloadApplet *ma)
 		gboolean visible;
 		char *key;
 
-		/* This is a special case to handle migration from an
-		 * older version of netload to a newer one in the
-		 * 2.25.1 release. */
-		if (g_strcmp0 ("netload2", graph_types[i].name) == 0) {
-		  key = g_strdup ("view_netload");
-		} else {
-		  key = g_strdup_printf ("view_%s", graph_types[i].name);
-		}
-		visible = panel_applet_gconf_get_bool (ma->applet, key, NULL);
+		key = g_strdup_printf ("view-%s", graph_types[i].name);
+		visible = g_settings_get_boolean (ma->settings, key);
 		g_free (key);
 
 		ma->graphs[i] = load_graph_new (ma,
@@ -429,14 +436,14 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	
 	if ( (orientation == PANEL_APPLET_ORIENT_UP) || 
 	     (orientation == PANEL_APPLET_ORIENT_DOWN) ) {
-	     	ma->box = gtk_hbox_new(FALSE, 0);
+			ma->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	}
 	else
-		ma->box = gtk_vbox_new(FALSE, 0);
+		ma->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	
 	gtk_container_add(GTK_CONTAINER(ma->applet), ma->box);
 			
-	/* create the NGRAPHS graphs, passing in their user-configurable properties with gconf. */
+	/* create the NGRAPHS graphs, passing in their user-configurable properties. */
 	multiload_create_graphs (ma);
 
 	/* only start and display the graphs the user has turned on */
@@ -455,28 +462,21 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	return;
 }
 
-static const GtkActionEntry multiload_menu_actions [] = {
-	{ "MultiLoadProperties", GTK_STOCK_PROPERTIES, N_("_Preferences"),
-	  NULL, NULL,
-	  G_CALLBACK (multiload_properties_cb) },
-	{ "MultiLoadRunProcman", GTK_STOCK_EXECUTE, N_("_Open System Monitor"),
-	  NULL, NULL,
-	  G_CALLBACK (start_procman_cb) },
-	{ "MultiLoadHelp", GTK_STOCK_HELP, N_("_Help"),
-	  NULL, NULL,
-	  G_CALLBACK (help_cb) },
-	{ "MultiLoadAbout", GTK_STOCK_ABOUT, N_("_About"),
-	  NULL, NULL,
-	  G_CALLBACK (about_cb) }
-};		
+static const GActionEntry multiload_menu_actions [] = {
+	{ "run",         start_procman_cb,        NULL, NULL, NULL },
+	{ "preferences", multiload_properties_cb, NULL, NULL, NULL },
+	{ "help",        help_cb,                 NULL, NULL, NULL },
+	{ "about",       about_cb,                NULL, NULL, NULL }
+};
 
 /* create a box and stuff the load graphs inside of it */
 static gboolean
 multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 {
 	MultiloadApplet *ma;
-	GConfClient *client;
-	GtkActionGroup *action_group;
+	GSettings *settings;
+	GSimpleActionGroup *action_group;
+	GAction *action;
 	gchar *ui_path;
 	
 	ma = g_new0(MultiloadApplet, 1);
@@ -490,43 +490,40 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	g_set_application_name (_("System Monitor"));
 
 	gtk_window_set_default_icon_name ("utilities-system-monitor");
-	panel_applet_set_background_widget (applet, GTK_WIDGET(applet));
-	
-	panel_applet_add_preferences (applet, "/schemas/apps/multiload/prefs", NULL);
+
+	ma->settings = panel_applet_settings_new (applet, MULTILOAD_SCHEMA);
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
-	action_group = gtk_action_group_new ("Multiload Applet Actions");
-	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-	gtk_action_group_add_actions (action_group,
-				      multiload_menu_actions,
-				      G_N_ELEMENTS (multiload_menu_actions),
-				      ma);
+	action_group = g_simple_action_group_new ();
+	g_action_map_add_action_entries (G_ACTION_MAP (action_group),
+	                                 multiload_menu_actions,
+	                                 G_N_ELEMENTS (multiload_menu_actions),
+	                                 ma);
 	ui_path = g_build_filename (MULTILOAD_MENU_UI_DIR, "multiload-applet-menu.xml", NULL);
-	panel_applet_setup_menu_from_file (applet, ui_path, action_group);
+	panel_applet_setup_menu_from_file (applet, ui_path, action_group, GETTEXT_PACKAGE);
 	g_free (ui_path);
 
+	gtk_widget_insert_action_group (GTK_WIDGET (applet), "multiload",
+	                                G_ACTION_GROUP (action_group));
 
-	if (panel_applet_get_locked_down (applet)) {
-		GtkAction *action;
+	action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "preferences");
+	g_object_bind_property (applet, "locked-down", action, "enabled",
+	                        G_BINDING_DEFAULT|G_BINDING_INVERT_BOOLEAN|G_BINDING_SYNC_CREATE);
 
-		action = gtk_action_group_get_action (action_group, "MultiLoadProperties");
-		gtk_action_set_visible (action, FALSE);
-	}
+	settings = g_settings_new (GNOME_DESKTOP_LOCKDOWN_SCHEMA);
 
-	client = gconf_client_get_default ();
-	if (gconf_client_get_bool (client, "/desktop/gnome/lockdown/inhibit_command_line", NULL) ||
+	if (g_settings_get_boolean (settings, DISABLE_COMMAND_LINE) ||
 	    panel_applet_get_locked_down (applet)) {
-		GtkAction *action;
-
 		/* When the panel is locked down or when the command line is inhibited,
 		   it seems very likely that running the procman would be at least harmful */
-		action = gtk_action_group_get_action (action_group, "MultiLoadRunProcman");
-		gtk_action_set_visible (action, FALSE);
+		action = g_action_map_lookup_action (G_ACTION_MAP (action_group), "run");
+		g_simple_action_set_enabled (G_SIMPLE_ACTION (action), FALSE);
 	}
 
+	g_object_unref (settings);
 	g_object_unref (action_group);
 
-	g_signal_connect(G_OBJECT(applet), "change_size",
+	g_signal_connect(G_OBJECT(applet), "size-allocate",
 				G_CALLBACK(multiload_change_size_cb), ma);
 	g_signal_connect(G_OBJECT(applet), "change_orient",
 				G_CALLBACK(multiload_change_orient_cb), ma);
